//+------------------------------------------------------------------+
//|                                                  CExperiment.mq5 |
//|                                            Copyright 2013, Rone. |
//|                                            rone.sergey@gmail.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2013, Rone."
#property link      "rone.sergey@gmail.com"
#property version   "1.00"
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
#include <Controls\Dialog.mqh>
#include <Controls\Button.mqh> 
//---
#define INDENT_LEFT     (11)      // indent from left (with allowance for border width)
#define INDENT_TOP      (11)      // indent from top (with allowance for border width)
#define CONTROLS_GAP_X  (5)       // gap by X coordinate
#define CONTROLS_GAP_Y  (5)       // gap by Y coordinate
//--- for buttons
#define BUTTON_WIDTH    (30)      // size by X coordinate
#define BUTTON_HEIGHT   (30)      // size by Y coordinate
#define BUTTONS_QTY     (5)       // buttond quantity  
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
class CMyApp : public CAppDialog {
private:
   CButton m_digits[BUTTONS_QTY];
   CButton m_letters[BUTTONS_QTY];
   
public:
   CMyApp() {}
   ~CMyApp() {} 
   virtual bool Create(const long chart, const string name, const int subwin, 
                        const int x1, const int y1, const int x2, const int y2);
   virtual bool OnEvent(const int id, const long &lparam, const double &dparam, const string &sparam);
   bool CreateDigitButtons();
   bool CreateLetterButtons();
   void OnClickButton();
   
private:
   bool CreateButton(CButton &button, string name, string text, int x1, int y1, int x2, int y2);
   bool OnClickDigit(int index);
   bool OnClickLetter(int index);
};
//+------------------------------------------------------------------+
//|                                                  |
//+------------------------------------------------------------------+
EVENT_MAP_BEGIN(CMyApp)
   ON_INDEXED_EVENT(ON_CLICK,m_digits,OnClickDigit)
   ON_INDEXED_EVENT(ON_CLICK,m_letters,OnClickLetter)
EVENT_MAP_END(CAppDialog)
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
bool CMyApp::Create(const long chart,const string name,const int subwin,
                  const int x1,const int y1,const int x2,const int y2)
{
   if ( !CAppDialog::Create(chart, name, subwin, x1, y1, x2, y2) ) {
      return(false);
   }
   if ( !CreateDigitButtons() ) {
      return(false);
   }
   if ( !CreateLetterButtons() ) {
      return(false);
   }
   return(true);
}
//---
bool CMyApp::CreateButton(CButton &button,string name,string text,int x1,int y1,int x2,int y2) {
   if ( !button.Create(m_chart_id, name, m_subwin, x1, y1, x2, y2) ) {
      return(false);
   }
   if ( !button.Text(text) ) {
      return(false);
   }
   if ( !Add(button) ) {
      return(false);
   }
   return(true);
}
//---
bool CMyApp::CreateDigitButtons(void) {
   int x1 = INDENT_LEFT;
   int y1 = INDENT_TOP;
   int x2 = x1 + BUTTON_WIDTH;
   int y2 = y1 + BUTTON_HEIGHT;
   
   for ( int i = 0; i < BUTTONS_QTY; i++ ) {
      if ( !CreateButton(m_digits[i], "Digit "+string(i), string(i), x1, y1, x2, y2) ) {
         return(false);
      }
      x1 = x2 + CONTROLS_GAP_X;
      x2 = x1 + BUTTON_WIDTH;
   }
   
   return(true);
}
//---
bool CMyApp::CreateLetterButtons(void) {
   int x1 = INDENT_LEFT;
   int y1 = INDENT_TOP + BUTTON_HEIGHT + CONTROLS_GAP_Y;
   int x2 = x1 + BUTTON_WIDTH;
   int y2 = y1 + BUTTON_HEIGHT;
   uchar ch = 'A'; 
   
   for ( int i = 0; i < BUTTONS_QTY; i++ ) {
      string text = CharToString(ch);
      if ( !CreateButton(m_letters[i], "Letter "+text, text, x1, y1, x2, y2) ) {
         return(false);
      }
      x1 = x2 + CONTROLS_GAP_X;
      x2 = x1 + BUTTON_WIDTH;
      ch += 1;
   }
   
   return(true);
}
//+------------------------------------------------------------------+
//|    m_digits                                 |
//+------------------------------------------------------------------+
bool CMyApp::OnClickDigit(int index)
  {
   Print("Digit ", m_digits[index].Text()," clicked!");
//--- handled
   return(true);
  }
//+------------------------------------------------------------------+
//|    m_letters                                |
//+------------------------------------------------------------------+
bool CMyApp::OnClickLetter(int index)
  {
   Print("Letter ", m_letters[index].Text()," clicked!");
//--- handled
   return(true);
  }
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
CMyApp myApp;
//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit() {
//---
   if ( !myApp.Create(0, "My App", 0, 20, 20, 221, 134) ) {
      return(-1);
   }
   myApp.Run();   
//---
   return(0);
}
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason) {
//---
   myApp.Destroy(reason); 
}
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick(){
//---  
}
//+------------------------------------------------------------------+
//| ChartEvent function                                              |
//+------------------------------------------------------------------+
void OnChartEvent(const int id,
                  const long &lparam,
                  const double &dparam,
                  const string &sparam)
{
//---
   myApp.ChartEvent(id, lparam, dparam, sparam);
//---   
}
//+------------------------------------------------------------------+
